@@ -1,6 +1,6 @@
 use {
-    crate::{state::*, errors::ErrorCode},
-    anchor_lang::{prelude::*},
+    crate::{errors::ErrorCode, state::*},
+    anchor_lang::prelude::*,
 };
 
 #[derive(Accounts)]
@@ -32,5 +32,5 @@ pub fn handler(ctx: Context<CreateClaimReceiptCtx>, target: Pubkey) -> Result<()
     claim_receipt.mint_count = ctx.accounts.token_manager.count;
     claim_receipt.token_manager = ctx.accounts.token_manager.key();
     claim_receipt.target = target;
-    return Ok(())
-}
\ No newline at end of file
+    Ok(())
+}
