@@ -1,6 +1,6 @@
 use {
-    crate::{state::*, errors::ErrorCode},
-    anchor_lang::{prelude::*},
+    crate::{errors::ErrorCode, state::*},
+    anchor_lang::prelude::*,
 };
 
 #[derive(Accounts)]
@@ -10,12 +10,12 @@ pub struct SetTransferAuthorityCtx<'info> {
 
     // issuer
     #[account(mut, constraint = issuer.key() == token_manager.issuer @ ErrorCode::InvalidIssuer)]
-    issuer: Signer<'info>
+    issuer: Signer<'info>,
 }
 
 pub fn handler(ctx: Context<SetTransferAuthorityCtx>, transfer_authority: Pubkey) -> Result<()> {
     // set token manager data
     let token_manager = &mut ctx.accounts.token_manager;
     token_manager.transfer_authority = Some(transfer_authority);
-    return Ok(())
-}
\ No newline at end of file
+    Ok(())
+}
